ffi_from_extended_record

Function ffi_from_extended_record 

pub fn ffi_from_extended_record<'a>(
    bytes: &'a [u8],
    allocator: &'a Bump,
) -> Result<(&'a mut LogMessage<'a>, &'a [u8]), MessageError>
Constructs a CPPLogsMessage from the provided bytes, assuming the bytes are in the format specified as in the [log encoding], and come from an Archivist LogStream with moniker, URL, and dropped logs output enabled. [log encoding] https://fuchsia.dev/fuchsia-src/development/logs/encodings

Lifetime and Borrowing

Strings within the returned LogMessage borrow directly from bytes. Therefore, bytes must remain valid and unmodified for the lifetime 'a of the returned LogMessage.