LogMessage

Struct LogMessage 

#[repr(C)]
pub struct LogMessage<'a> { pub severity: u8, pub tags: CppArray<'a, CppString<'a>>, pub pid: u64, pub tid: u64, pub dropped: u64, pub message: CppString<'a>, pub file: CppString<'a>, pub line: u64, pub moniker_tag: CppString<'a>, pub kvps: CppArray<'a, CppKeyValue<'a>>, pub timestamp: i64, }
Log message representation for FFI with C++.

Lifetime and Borrowing

Strings within LogMessage (tags, message, and string keys/values in kvps) borrow directly from the incoming encoded message buffer (bytes) when possible, or from the provided arena allocator (Bump). Consequently, the incoming message buffer MUST remain valid and unmodified for at least as long as the LogMessage is in use.

Fields

severity: u8

Severity of a log message.

tags: CppArray<'a, CppString<'a>>

Tags in a log message, guaranteed to be non-null.

pid: u64

Process ID from a LogMessage, or 0 if unknown

tid: u64

Thread ID from a LogMessage, or 0 if unknown

dropped: u64

Number of dropped log messages.

message: CppString<'a>

The UTF-encoded log message, guaranteed to be valid UTF-8.

file: CppString<'a>

Source file where the log was emitted, if any.

line: u64

Source line where the log was emitted, if any.

moniker_tag: CppString<'a>

Last segment of the moniker, used as a default log tag if needed.

kvps: CppArray<'a, CppKeyValue<'a>>

Key-value pairs in a log message.

timestamp: i64

Timestamp on the boot timeline of the log message, in nanoseconds.