ffi_from_extended_record

Function ffi_from_extended_record 

pub fn ffi_from_extended_record<'a, 'b>(
    bytes: &'a [u8],
    allocator: &'b Bump,
) -> Result<(&'b mut LogMessage<'b>, &'a [u8]), MessageError>
Constructs a CPPLogsMessage from the provided bytes, assuming the bytes are in the format specified as in the [log encoding], and come from

an Archivist LogStream with moniker, URL, and dropped logs output enabled. [log encoding] https://fuchsia.dev/fuchsia-src/development/logs/encodings